==> ace_5.6.3.orig.tar.gz: ACE_wrappers/TAO/orbsvcs/tests/Interoperable_Naming/ncontextext_client_i.h <==
// -*- C++ -*-
// $Id: ncontextext_client_i.h 77020 2007-02-12 13:56:49Z johnnyw $

// ===========================================================
//
// = LIBRARY
//    TAO/ORBSVCS/tests/SimpleNaming
//
// = FILENAME
//    ncontextext_client_i.h
//
// = DESCRIPTION
//    This class implements a simple CORBA client which
//    converts a Name to a string and viceversa, forms a IIOPNAME
//    url address and can resolve a stringified name.
//
// = AUTHORS
//    Priyanka Gontla <pgontla@ece.uci.edu>
//
//============================================================


#if !defined (NCONTEXTEXT_CLIENT_I_H)
#define NCONTEXTEXT_CLIENT_I_H

#include "Web_ServerC.h"
#include "orbsvcs/CosNamingC.h"

class NContextExt_Client_i
{
  // = TITLE
  //     NContextExt Client Implementation
  //
  // = DESCRIPTION
  //

 public:
  // = COnstructor and destructor.
  NContextExt_Client_i (void);
  ~NContextExt_Client_i (void);

  int run (void);
  // Execute the client example code.

  int init (int argc, char **argv);
  // Initialize the client communication endpoint with the server.

 private:

  int parse_args (void);
  // Parses the arguments passed on the command line.

  void print_values (CosNaming::Name name,
                     CORBA::String_var str_name,
                     CosNaming::Name nm,
                     CORBA::String_var obj_name,
                     CORBA::String_var url_string);
  // Prints the values of the original name, strigified name and
  // destringified name. Also, prints the value of the address of the
  // naming context, a name that identifies a binding in that naming
  // context and the corresponding iioploc URL
  // representation.

  char * get_name (void);
  // Generates a random name

  int argc_;
  // # of arguments on the command line.

  char **argv_;
  // arguments from command line.

  CosNaming::NamingContextExt_var naming_context_;
  // Naming context

  CORBA::Boolean view_;
  // Flag to check if '-v' option is set.

};

#endif /* NCONTEXTEXT_CLIENT_I_H */

==> ace_5.7.7+dfsg.orig.tar.gz: ACE_wrappers/TAO/orbsvcs/tests/Interoperable_Naming/ncontextext_client_i.h <==
// -*- C++ -*-
// $Id: ncontextext_client_i.h 82203 2008-06-26 15:10:39Z sma $

// ===========================================================
//
// = LIBRARY
//    TAO/ORBSVCS/tests/SimpleNaming
//
// = FILENAME
//    ncontextext_client_i.h
//
// = DESCRIPTION
//    This class implements a simple CORBA client which
//    converts a Name to a string and viceversa, forms a IIOPNAME
//    url address and can resolve a stringified name.
//
// = AUTHORS
//    Priyanka Gontla <pgontla@ece.uci.edu>
//
//============================================================


#if !defined (NCONTEXTEXT_CLIENT_I_H)
#define NCONTEXTEXT_CLIENT_I_H

#include "Web_ServerC.h"
#include "orbsvcs/CosNamingC.h"

class NContextExt_Client_i
{
  // = TITLE
  //     NContextExt Client Implementation
  //
  // = DESCRIPTION
  //

 public:
  // = COnstructor and destructor.
  NContextExt_Client_i (void);
  ~NContextExt_Client_i (void);

  int run (void);
  // Execute the client example code.

  int init (int argc, ACE_TCHAR *argv[]);
  // Initialize the client communication endpoint with the server.

 private:

  int parse_args (void);
  // Parses the arguments passed on the command line.

  void print_values (CosNaming::Name name,
                     CORBA::String_var str_name,
                     CosNaming::Name nm,
                     CORBA::String_var obj_name,
                     CORBA::String_var url_string);
  // Prints the values of the original name, strigified name and
  // destringified name. Also, prints the value of the address of the
  // naming context, a name that identifies a binding in that naming
  // context and the corresponding iioploc URL
  // representation.

  char * get_name (void);
  // Generates a random name

  int argc_;
  // # of arguments on the command line.

  ACE_TCHAR **argv_;
  // arguments from command line.

  CosNaming::NamingContextExt_var naming_context_;
  // Naming context

  CORBA::Boolean view_;
  // Flag to check if '-v' option is set.

};

#endif /* NCONTEXTEXT_CLIENT_I_H */
